# CHANGELOG

## 1.1.0

- Added Category API Calls

- Added `document.upload()`, convenient function that supports both client and server side uplaods

- Some Intellisense Improvements

## 1.1.25

- Normalized snake case for all inputs

- Improved Intellisense

- Dynamic Intellisense and Types for Features and Tables
